docs.rs failed to build bb-ir-0.3.4
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Foundation IR crate. Hosts prost-generated ONNX + bb.core
bindings and the cross-crate types every other crate depends on:
- [
ids] —PeerId,NodeSiteId,OpRef,ComponentRef,ExecId,CommandId,RequestId. - [
wire] —TypeNodedenotations + canonical statics. - [
tensor] —Scalar,Tensortraits +Dense<T>storage. - [
slot_value] — universalSlotValuetrait. - [
atomic] —AtomicOpsetDecl,AtomicOpDecl,AtomicOpKind.